@@ -5,7 +5,7 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.38.1")
+(defparameter *autoconf-version* "5.39.0")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
@@ -17,6 +17,9 @@
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
 (defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
+
+;; This will be T if this was a lisp-only build
+(defparameter *autoconf-lisp-only-build* (eq t '@lisp_only_build@))
  
-(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.38.1")
+(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.39.0")
 (defparameter *maxima-default-layout-autotools* "true")
